/*  JBCore.java
 *
 *  Copyright (C) 2003 Dominik Werthmueller
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package ch.fulgur.jarbuilder;

import java.awt.*;
import javax.swing.*;
import java.io.*;



/**
 * JBCore.java
 *
 * @author Dominik Werthmueller
 *
 */
public class JBCore implements Runnable {

	private DefaultListModel FileList;
	private JPanel panelMain;
	private Panel1 panel1;
	private Panel2 panel2;
	private Panel3 panel3;
	private Panel4 panel4;
	private JarWriter jw;
	private JarBuilder jarbuilder;
	private SearchMain searchmain;
	private VarUtils varutils;
	private File lastDirectory;
	private String mainClass;
	private boolean SearchMainShowing = false;
	private JFileChooser fc;

	// ---------- start methods ----------
	/**
	 * return the FileList
	 *
	 * @return ListModel
	 */
	public DefaultListModel getFileList() {
		return FileList;
	}


	/**
	 * add an element to the FileList
	 *
	 * @param Object to add
	 */
	public void addElementToFileList(Object o) {
		FileList.addElement(o);
	}


	/**
	 * remove an element from the FileList
	 *
	 * @param Index of the element that should be removed
	 */
	public void removeElementFromFileList(int i) {
		FileList.remove(i);
	}


	/**
	 * return an element from the FileList as String
	 *
	 * @param the element's index
	 * @return the element as String
	 */
	public String getElementFromFileList(int i) {
		return FileList.get(i).toString();
	}


	/**
	 * return the size of the FileList
	 *
	 * @return the size of the FileList
	 */
	public int getFileListSize() {
		return FileList.size();
	}


	/**
	 * delete all elements of the FileList
	 */
	public void clearFileList() {
		FileList.clear();
	}


	/**
	 * sets the SearchMainShowing variable
	 *
	 * @param state to set
	 */
	public void setSearchMainShowing(boolean b) {
		SearchMainShowing = b;
	}


	/**
	 * sets the MainClass variable
	 *
	 * @param String to set
	 */
	public void setMainClass(String s) {
		mainClass = s;
	}


	/**
	 * the run method of the Runnable Interface
	 */
	public void run() {
		int compressionRate;
		boolean writerReturn;

		// set the compression rate
		compressionRate = panel3.getCompressionRate();

		JFileChooser fc2 = new JFileChooser();
		
		// set the last path and the filename
		if (mainClass != null && lastDirectory != null) {
			fc2.setSelectedFile(new File(lastDirectory + VarUtils.FILESEPARATOR + mainClass + ".jar"));
		}
		else fc2.setSelectedFile(new File(lastDirectory + VarUtils.FILESEPARATOR + "test.jar"));

		fc2.setDialogTitle("Save Jar File");
		int returnVal = fc2.showSaveDialog(jarbuilder);
		if (returnVal == JFileChooser.APPROVE_OPTION) {
			// here starts the creation process
			panel1.setStateOfElements(false);
			panel2.setStateOfElements(false);
			panel3.setStateOfElements(false);
			this.setExtLoad(true);

			// the most important method call
			writerReturn = jw.createJar(fc2.getSelectedFile(), compressionRate);

			// here ends the creation process
			Toolkit.getDefaultToolkit().beep();
			this.setExtLoad(false);
			panel1.setStateOfElements(true);
			panel2.setStateOfElements(true);
			panel3.setStateOfElements(true);

			if (writerReturn) {
				JOptionPane.showMessageDialog(jarbuilder, "Jar File was successfully created."
        			, "JarBuilder", JOptionPane.INFORMATION_MESSAGE);
			}
			else {
				JOptionPane.showMessageDialog(jarbuilder, "The Jar File Creation Process was stopped\n" +
				"because of an error or a user interruption."
        			, "JarBuilder", JOptionPane.ERROR_MESSAGE);

			}
		}
	}



	/**
	 * this method prepares everything for creating the jar file
	 */
	public void prepareJar() {
		// exit when the filelist is empty
		if (this.getFileListSize() == 0) return;

		String[] s = new String[this.getFileListSize()];

		for (int i = 0; i < this.getFileListSize(); i++) {
			s[i] = this.getElementFromFileList(i);
		}

		jw.setFiles(s);

		// manifest
		if (!panel2.radioButtonisSelected(3)) {
			jw.setIncludeManifest(true);
		}

		// auto-generate manifest
		if (panel2.radioButtonisSelected(0)) {
			jw.setIncludeManifest(true);
			jw.setLoadManifest(false);
			searchMain();
			return;
		}
		
		// write own manifest
		if (panel2.radioButtonisSelected(2)) {
			int length = 0;
			jw.setManifest("");

			// cannot directly read all chars, eol in files is platform dependent
			try {
				for (int i = 0; i < panel2.getTAManifest().getLineCount(); i++) {
					if (panel2.getTAManifest().getLineCount() - i != 1) length = panel2.getTAManifest().getLineEndOffset(i) - panel2.getTAManifest().getLineStartOffset(i) - 1;
					else length = panel2.getTAManifest().getLineEndOffset(i) - panel2.getTAManifest().getLineStartOffset(i);

					jw.setManifest(jw.getManifest() + panel2.getTAManifest().getText(panel2.getTAManifest().getLineStartOffset(i), 
						length) + System.getProperty("line.separator"));
				}
			} catch (Exception e) {
			}
			jw.setLoadManifest(false);
		}

		// load own manifest
		if (panel2.radioButtonisSelected(1)) {
			JFileChooser fc3 = new JFileChooser();

			fc3.setDialogTitle("Load own Manifest");
			if (lastDirectory != null) fc3.setCurrentDirectory(lastDirectory);
			int returnVal = fc3.showOpenDialog(jarbuilder);
			if (returnVal == JFileChooser.APPROVE_OPTION) {
				jw.setIncludeManifest(true);
				jw.setLoadManifest(true);
				jw.setManifestFile(fc3.getSelectedFile());
			}
			else {
				jw.setIncludeManifest(false);
				return;
			}
		}


		// no manifest
		if (panel2.radioButtonisSelected(3)) {
			jw.setIncludeManifest(false);
		}

		Thread t = new Thread(this);
		t.start();
	}


	/**
	 * this method searches the main method
	 */
	private void searchMain() {
		if (!SearchMainShowing) {
			String mainFile = "";

			String[] s = new String[this.getFileListSize()];

			for (int i = 0; i < this.getFileListSize(); i++) {
				s[i] = this.getElementFromFileList(i);
			}

			int xpos = (int)jarbuilder.getLocation().getX() + jarbuilder.getWidth() / 2 - 550 / 2;
			int ypos = (int)jarbuilder.getLocation().getY() + jarbuilder.getHeight() / 2 - 200 / 2;
			searchmain = new SearchMain(this, xpos, ypos, s, jw);

			Thread t = new Thread(searchmain);
			t.start();
		}
	}



	/**
	 * this method creates the jar file
	 */
	public void buildJar(String m) {
		mainClass = m;
		Thread t = new Thread(this);
		t.start();
	}


	/**
	 * this method removes an entry of the list
	 */
	public void removeEntry() {
		int[] selection;
		selection = panel1.getSelIndicesFromList();

		if (selection.length > 0) {
			for (int i = selection.length - 1; i >= 0; i--) {
				this.removeElementFromFileList(selection[i]);
			}
		}
	}


	/**
	 * this method loads and unloads the extension panel
	 */
	private void setExtLoad(boolean b) {
		if (b) {
			GridBagConstraints a = varutils.getDefaultGridBagCons();
			a.gridx = 0;
			a.gridy = 4;
			panelMain.add(panel4, a);
		}
		else {
			panelMain.remove(panel4);
			panel4.setMessageText("Preparing for creating Jar File...");
			panel4.setBarText("checking files...");
			panel4.setBarValue(0);
		}

		jarbuilder.pack();
	}




	/**
	 * this method loads files for a new jar file
	 */
	public void loadFiles() {

		// configure load dialog
		fc = new JFileChooser();
		fc.setDialogTitle("Load file(s)");
		fc.setMultiSelectionEnabled(true);
		fc.setFileSelectionMode(JFileChooser.FILES_AND_DIRECTORIES);
		if (lastDirectory != null) fc.setCurrentDirectory(lastDirectory);

		int returnVal = fc.showOpenDialog(jarbuilder);
		if (returnVal == JFileChooser.APPROVE_OPTION) {
        		File[] Files = fc.getSelectedFiles();
        		for (int i = 0; i < Files.length; i++) this.addElementToFileList(Files[i].toString());
        		lastDirectory = fc.getCurrentDirectory();
       		 }
	}


	/*
	 * stop the jar building process
	 */
	public void abortBuildProcess() {
		jw.setAborted(true);
	}

	// ---------- end methods ----------

	// ---------- Constructor ----------
	public JBCore(JarBuilder j, JPanel p0, Panel1 p1, Panel2 p2, Panel3 p3, Panel4 p4) {
		jarbuilder = j;
		panelMain = p0;
		panel1 = p1;
		panel2 = p2;
		panel3 = p3;
		panel4 = p4;

		FileList = new DefaultListModel();
		panel1.setListModel(FileList);

		jw = new JarWriter(panel4);

		varutils = new VarUtils();
	}

}
