/*  JBMenu.java
 *
 *  Copyright (C) 2002-2003 Dominik Werthmueller
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */ 
 
package ch.fulgur.jarbuilder;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;



/** 
 * JBMenu.java
 *
 * @author Dominik Werthmueller
 * 
 */
public class JBMenu extends JMenuBar implements ActionListener {
	
	private JBMenuInterface MenuMethods;
	
	/**
	 * Implements the abstract method ActionListener.actionPerformed
	 * 
	 */
	public void actionPerformed(ActionEvent e) {
		String s = "";
		
		/* 
		 * search for the event source in the menu tree
		 * leave the whole block when the source has been found
		 */
		leave_block:
		for (int i = 0; i < this.getMenuCount(); i++) {
			for (int j = 0; j < this.getMenu(i).getMenuComponentCount(); j++) {
				if (this.getMenu(i).getMenuComponent(j).equals(e.getSource())) {
					s = Integer.toString(i) + Integer.toString(j);
					break leave_block;
				}
			}
		}
		
		/*
		* assign the correct methods to the menu entries
		*/
		switch (Integer.parseInt(s)) {
			case 0 :
				MenuMethods.requestMenuCreateJar();
				break;
			case 2 :
				MenuMethods.requestMenuQuit();
				break;
			case 10 :
				MenuMethods.requestMenuAddFiles();
				break;
			case 12 :
				MenuMethods.requestMenuRemoveFiles();
				break;
			case 13 :
				MenuMethods.requestMenuClearList();
				break;
			case 20 :
				MenuMethods.requestMenuHelpContents();
				break;
			case 22 :
				MenuMethods.requestMenuAbout();
				break;
		}
		
		
	}
	
	
	/**
	 * Constructor for Menu
	 */
	public JBMenu(JBMenuInterface a) {
		MenuMethods = a;
		VarUtils varutils = new VarUtils();
		
		// menu "File"
		JMenu mFile = new JMenu("File");
		mFile.setMnemonic('F');
			
			// submenu "Create Jar File"
			JMenuItem mCreate = new JMenuItem("Create Jar File", varutils.loadIcon("Jar16.gif"));
			mCreate.setMnemonic('C');
			mCreate.setAccelerator(KeyStroke.getKeyStroke('C', Event.CTRL_MASK));
			mCreate.addActionListener(this);
			mFile.add(mCreate);
		
			// separator
			mFile.addSeparator();
		
			// submenu "Quit"
			JMenuItem mQuit = new JMenuItem("Quit", varutils.loadIcon("Stop16.gif"));
			mQuit.setMnemonic('Q');
			mQuit.setAccelerator(KeyStroke.getKeyStroke('Q', Event.CTRL_MASK));
			mQuit.addActionListener(this);
			mFile.add(mQuit);
			
		add(mFile);
		
		// menu "Edit"
		JMenu mEdit = new JMenu("Edit");
		mEdit.setMnemonic('E');
		
			// submenu "Add File(s)"
			JMenuItem mAdd = new JMenuItem("Add File(s)", varutils.loadIcon("Add16.gif"));
			mAdd.setMnemonic('A');
			mAdd.setAccelerator(KeyStroke.getKeyStroke('A', Event.CTRL_MASK));
			mAdd.addActionListener(this);
			mEdit.add(mAdd);
			
			// separator
			mEdit.addSeparator();
			
			// submenu "Remove File(s)"
			JMenuItem mRemove = new JMenuItem("Remove File(s)", varutils.loadIcon("Remove16.gif"));
			mRemove.setMnemonic('R');
			mRemove.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_DELETE, 0));
			mRemove.addActionListener(this);
			mEdit.add(mRemove);
			
			// submenu "Clear List"
			JMenuItem mClear = new JMenuItem("Clear List", varutils.loadIcon("Delete16.gif"));
			mClear.setMnemonic('C');
			mClear.addActionListener(this);
			mEdit.add(mClear);
			
		add(mEdit);
		
		// menu "Help"
		JMenu mHelp = new JMenu("Help");
		mHelp.setMnemonic('H');
		
			// submenu "Help Contents"
			JMenuItem mContents = new JMenuItem("Help Contents", varutils.loadIcon("Help16.gif"));
			mContents.setMnemonic('C');
			mContents.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_F1, 0));
			mContents.addActionListener(this);
			mHelp.add(mContents);
			
			// separator
			mHelp.addSeparator();
			
			// submenu "About JarBuilder"
			JMenuItem mAbout = new JMenuItem("About JarBuilder", varutils.loadIcon("About16.gif"));
			mAbout.setMnemonic('A');
			mAbout.addActionListener(this);
			mHelp.add(mAbout);
			
		add(mHelp);
	}		
}
