/*  Panel3.java
 *
 *  Copyright (C) 2002-2003 Dominik Werthmueller
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package ch.fulgur.jarbuilder;

import java.awt.*;
import javax.swing.*;
import javax.swing.event.*;



/** 
 * Panel3.java
 *
 * @author Dominik Werthmueller
 * 
 */
public class Panel3 extends SuperPanel {
	
	private JSlider slCompress;
	private JButton bCreate, bClearAll, bQuit;
	private JLabel lbCompress; 


	/**
	 * return the compression rate selected by the jslider slCompress
	 * @return compression rate
	 */
	public int getCompressionRate() {
		return slCompress.getValue();
	}
	
	
	/**
	 * set the compression rate by changing the slCompress jslider
	 * @param the compression rate to set (0-9)
	 */
	public void setCompressionRate(int cr) {
		slCompress.setValue(cr);
	}


	/**
	 *	enable or disables all components of panel 3
	 * @param state true for enable, false for disable
	 */
	public void setStateOfElements(boolean state) {
		slCompress.setEnabled(state);
		bCreate.setEnabled(state);
		bClearAll.setEnabled(state);
		bQuit.setEnabled(state);
	}


	/**
	 * Constructor for Panel3
	 */
	public Panel3(JBButtonInterface b) {
		super(b);
		VarUtils varutils = new VarUtils();
		
		GridLayout gl1 = new GridLayout(2, 1);
		setLayout(gl1);
		setBorder(BorderFactory.createTitledBorder("3. Step: Create Jar File"));

		// panel for options
		JPanel panelOptions = new JPanel(new FlowLayout(FlowLayout.LEFT));
		
		panelOptions.add(new JLabel("Compression Rate (0: no Compression; 9: best) :"));
			
		slCompress = new JSlider(0, 9, 9);
		slCompress.setMajorTickSpacing(1);
		slCompress.setPaintTicks(true);
		slCompress.setSnapToTicks(true);
		slCompress.addChangeListener(new ChangeListener() {
			public void stateChanged(ChangeEvent e) {
				lbCompress.setText(Integer.toString(slCompress.getValue()));
			}
		});
		panelOptions.add(slCompress);
		
		lbCompress = new JLabel(Integer.toString(slCompress.getValue()));
		panelOptions.add(lbCompress);
		
		
		// option panel to panel 3
		add(panelOptions);
		

		// panel for buttons
		GridLayout gl2 = new GridLayout(1, 3);
		gl2.setHgap(8);
		gl2.setVgap(8);
		JPanel panelButtons = new JPanel(gl2);

		bCreate = new JButton("Create Jar File", varutils.loadIcon("Jar24.gif"));
		bCreate.setName("3");
		bCreate.addActionListener(this);
		bCreate.setVerticalTextPosition(AbstractButton.BOTTOM);
		bCreate.setHorizontalTextPosition(AbstractButton.CENTER);
		panelButtons.add(bCreate);

		bClearAll = new JButton("Clear All", varutils.loadIcon("Delete24.gif"));
		bClearAll.setName("4");
		bClearAll.addActionListener(this);
		bClearAll.setVerticalTextPosition(AbstractButton.BOTTOM);
		bClearAll.setHorizontalTextPosition(AbstractButton.CENTER);
		panelButtons.add(bClearAll);

		bQuit = new JButton("Quit", varutils.loadIcon("Stop24.gif"));
		bQuit.setName("5");
		bQuit.addActionListener(this);
		bQuit.setVerticalTextPosition(AbstractButton.BOTTOM);
		bQuit.setHorizontalTextPosition(AbstractButton.CENTER);
		panelButtons.add(bQuit);

		// button panel to panel 3
		add(panelButtons);
	}
}
