/*  SearchMain.java
 *
 *  Copyright (C) 2002-2003 Dominik Werthmueller
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */ 		

package ch.fulgur.jarbuilder;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import java.io.*;
import java.util.*;
	
	
	
/** 
 * VarUtils.java
 * 
 * This class searches main methods in class / java files
 *
 * @author Dominik Werthmueller
 * 
 */	
public class SearchMain extends JDialog implements Runnable {
		
		private String[] main;
		private String mainClass;
		private JBCore jbcore;
		private JarWriter jarwriter;
		
		private JLabel lText;
		private JProgressBar pbBar;
		private JList lList;
		private DefaultListModel list;



		/**
		 * leave the class
		 *
		 */
		private void leave() {
			// copies the name of the main class into a String
			mainClass = list.get(lList.getSelectedIndex()).toString();
			mainClass = mainClass.substring(mainClass.lastIndexOf(VarUtils.FILESEPARATOR) + 1, mainClass.indexOf(".class"));
			jbcore.setMainClass(mainClass);

			jarwriter.setManifest("Main-Class: " + mainClass);
			jbcore.buildJar(mainClass);

			jbcore.setSearchMainShowing(false);
			setVisible(false);
		}
		


		/**
		 * this method sets the value of the progress bar
		 *
		 * @param value to set
		 */
		private void setBar(final int v) {
			SwingUtilities.invokeLater(new Runnable() {
				public void run() {
					pbBar.setValue(v);
				}
			});	
		}


		/**
		 * this method sets the message text
		 *
		 * @param text to set
		 */
		private void setMessage(final String s) {
			SwingUtilities.invokeLater(new Runnable() {
				public void run() {
					lText.setText(s);
				}
			});	
		}
		
		
		/**
		 * this method adds an element to the JList
		 *
		 * @param Object to add
		 */
		private void addListElement(final Object o) {
			try {
				SwingUtilities.invokeAndWait(new Runnable() {
					public void run() {
						list.addElement(o);
					}
				});
			} catch (Exception e) {}	
		}	

		 
		/**
		 * run method of the Runnable interface
		 *
		 */
		public void run() {
			String line;
			boolean inList;
			ArrayList classes = new ArrayList();
			
			for (int i = 0; i < main.length; i++) {
				if ((main[i].endsWith(".class")) == true) classes.add(main[i]);	
			}

			pbBar.setMinimum(0);
			pbBar.setMaximum(classes.size());
			
			for (int i = 0; i < classes.size(); i++) {
				try {
					setMessage("checking " + classes.get(i) + " for main method...");
					setBar(i);
					inList = false;
					
					BufferedReader in = new BufferedReader(new FileReader(classes.get(i).toString()));
					while ((line = in.readLine()) != null) {
						if (line.indexOf("main") != -1) {
							// check if the class is already in the list
							for (int a = 0; a < list.size(); a++) {
								if (list.get(a).toString().equals(classes.get(i)) == true) {
									inList = true;
									break;
								}
							}
							if (inList == false) addListElement(classes.get(i));
						}
					}
					in.close();
				}
				catch (Exception e) {
				}

			}
			
			if (list.size() == 0) {
				pbBar.setMaximum(1);
				setBar(1);
				setMessage("No main method found");
			}
			else {
				setBar(pbBar.getMaximum());
				setMessage("Finished search.");
			}
		}
		
		
		/**
		 * constructs a SearchMain class with an array of file names.
		 *
		 */
		public SearchMain(JBCore j, int xpos, int ypos, String[] s, JarWriter jw) {
			jbcore = j;
			
			setTitle("Searching for classes containing a main method");
			setResizable(false);
			setSize(550, 200);
			setLocation(xpos, ypos);
			getContentPane().setLayout(new BorderLayout());
			
			JPanel pNorth = new JPanel(new GridLayout(2,1));
			lText = new JLabel();
			pNorth.add(lText);
			pbBar = new JProgressBar();
			pbBar.setStringPainted(true);
			pNorth.add(pbBar);
			getContentPane().add(pNorth, BorderLayout.NORTH);
			
			list = new DefaultListModel();
			lList = new JList(list);
			JScrollPane scPane = new JScrollPane(lList);
			getContentPane().add(scPane, BorderLayout.CENTER);
			
			JPanel pSouth = new JPanel(new FlowLayout(FlowLayout.CENTER));
			JButton bOk = new JButton("Ok");
			pSouth.add(bOk);
			JButton bCancel = new JButton("Cancel");
			pSouth.add(bCancel);
			getContentPane().add(pSouth, BorderLayout.SOUTH);
			
			// WindowListener
			addWindowListener(new WindowAdapter() {
			public void windowClosing(WindowEvent e) {
				jbcore.setSearchMainShowing(false);
				dispose();
			}
			});

			// Button "Ok"
			bOk.addActionListener(new ActionListener() {
				public void actionPerformed(ActionEvent e) {
					if (lList.getSelectedIndex() != -1) leave();
				}
			});

			// Button "Cancel"
			bCancel.addActionListener(new ActionListener() {
				public void actionPerformed(ActionEvent e) {
					jbcore.setSearchMainShowing(false);
					dispose();
				}
			});

	
			jarwriter = jw;
			main = s;	
			jbcore.setSearchMainShowing(true);
			setVisible(true);	
		}	
}

